@@ -1,4 +1,4 @@
-# $Id: mirror_sites.tcl 68253 2010-05-29 23:39:16Z jmr@macports.org $
+# $Id: mirror_sites.tcl 80216 2011-07-07 03:09:52Z blair@macports.org $
 # mirror_sites.tcl
 #
 # List of master site classes for use in Portfiles
@@ -27,12 +27,10 @@ set portfetch::mirror_sites::sites(apache) {
     ftp://ftp.infoscience.co.jp/pub/net/apache/dist/
     http://apache.multidist.com/
     http://mirror.internode.on.net/pub/apache/
-    http://mirror.pacific.net.au/pub1/apache-dist/
-    http://apache.wildit.net.au/
-    http://www.mirrorservice.org/sites/ftp.apache.org/
     http://mirror.aarnet.edu.au/pub/apache/
     http://apache-mirror.dkuug.dk/
     http://apache.is.co.za/
+    http://mirror.facebook.net/apache/
     http://www.apache.org/dist/
     http://archive.apache.org/dist/
 }
@@ -71,6 +69,16 @@ set portfetch::mirror_sites::sites(debian) {
     http://ftp2.de.debian.org/debian/pool/main/:nosubdir
 }
 
+set portfetch::mirror_sites::sites(fink) {
+    http://distfiles.hnd.jp.asi.finkmirrors.net/:nosubdir
+    http://distfiles.ber.de.eu.finkmirrors.net/:nosubdir
+    http://distfiles.hel.fi.eu.finkmirrors.net/:nosubdir
+    http://distfiles.dub.ie.eu.finkmirrors.net/:nosubdir
+    http://distfiles.ams.nl.eu.finkmirrors.net/:nosubdir
+    http://distfiles.sjc.ca.us.finkmirrors.net/:nosubdir
+    http://distfiles.master.finkmirrors.net/:nosubdir
+}
+
 set portfetch::mirror_sites::sites(freebsd) {
     ftp://ftp5.freebsd.org/pub/FreeBSD/ports/distfiles/:nosubdir
     ftp://ftp5.freebsd.org/pub/FreeBSD/ports/local-distfiles/:nosubdir
@@ -86,8 +94,6 @@ set portfetch::mirror_sites::sites(freebsd) {
     ftp://ftp.se.FreeBSD.org/pub/FreeBSD/ports/local-distfiles/:nosubdir
     http://mirror.aarnet.edu.au/pub/FreeBSD/ports/distfiles/:nosubdir
     http://mirror.aarnet.edu.au/pub/FreeBSD/ports/local-distfiles/:nosubdir
-    http://www.mirrorservice.org/sites/ftp.freebsd.org/pub/FreeBSD/ports/distfiles/:nosubdir
-    http://www.mirrorservice.org/sites/ftp.freebsd.org/pub/FreeBSD/ports/local-distfiles/:nosubdir
     ftp://ftp.FreeBSD.org/pub/FreeBSD/ports/distfiles/:nosubdir
     ftp://ftp.FreeBSD.org/pub/FreeBSD/ports/local-distfiles/:nosubdir
 }
@@ -126,9 +132,7 @@ set portfetch::mirror_sites::sites(gentoo) {
     http://mirror.switch.ch/ftp/mirror/gentoo/distfiles/:nosubdir
     http://ftp.linux.org.tr/gentoo/distfiles/:nosubdir
     http://mirror.bytemark.co.uk/gentoo/distfiles/:nosubdir
-    http://www.mirrorservice.org/sites/www.ibiblio.org/gentoo/distfiles/:nosubdir
     http://gentoo.kiev.ua/ftp/distfiles/:nosubdir
-    http://mirror.pacific.net.au/linux/Gentoo/distfiles/:nosubdir
     http://ftp.swin.edu.au/gentoo/distfiles/:nosubdir
     http://ftp.iij.ad.jp/pub/linux/gentoo/distfiles/:nosubdir
     http://mirror2.corbina.ru/gentoo-distfiles/distfiles/:nosubdir
@@ -137,16 +141,15 @@ set portfetch::mirror_sites::sites(gentoo) {
     http://gentoo.in.th/distfiles/:nosubdir
     http://mirror.isoc.org.il/pub/gentoo/distfiles/:nosubdir
     http://mirror.neolabs.kz/gentoo/pub/distfiles/:nosubdir
+    http://mirror.facebook.net/gentoo/distfiles/:nosubdir
 }
 
 set portfetch::mirror_sites::sites(gimp) {
-    ftp://ftp.gimp.org/pub/
     ftp://ftp.gtk.org/pub/
     http://ftp.gtk.org/pub/
     http://gimp.mirrors.hoobly.com/
     ftp://gd.tuwien.ac.at/graphics/gimp/
     http://ftp.iut-bm.univ-fcomte.fr/gimp/
-    http://gimp.krecio.pl/
     ftp://ftp.gwdg.de/pub/misc/grafik/gimp/
     http://ftp.gwdg.de/pub/misc/grafik/gimp/
     ftp://ftp.esat.net/mirrors/ftp.gimp.org/pub/
@@ -161,7 +164,6 @@ set portfetch::mirror_sites::sites(gimp) {
 set portfetch::mirror_sites::sites(gnome) {
     ftp://ftp.cse.buffalo.edu/pub/Gnome/
     http://www.gtlib.cc.gatech.edu/pub/gnome/
-    http://www.mirrorservice.org/sites/ftp.gnome.org/pub/GNOME/
     http://fr2.rpmfind.net/linux/gnome.org/
     http://mirror.aarnet.edu.au/pub/gnome/
     http://ftp.unina.it/pub/linux/GNOME/
@@ -182,28 +184,27 @@ set portfetch::mirror_sites::sites(gnome) {
 set portfetch::mirror_sites::sites(gnu) {
     http://mirrors.ibiblio.org/pub/mirrors/gnu/ftp/gnu/
     http://mirrors.kernel.org/gnu/
-    http://www.mirrorservice.org/sites/ftp.gnu.org/gnu/
+    http://mirror.facebook.net/gnu/gnu/
     ftp://ftp.funet.fi/pub/gnu/prep/
     ftp://ftp.kddlabs.co.jp/pub/gnu/gnu/
     ftp://ftp.kddlabs.co.jp/pub/gnu/old-gnu/
     ftp://ftp.dti.ad.jp/pub/GNU/
-    ftp://ftp.informatik.hu-berlin.de/pub/gnu/
+    ftp://ftp.informatik.hu-berlin.de/pub/gnu/gnu/
     ftp://ftp.lip6.fr/pub/gnu/
     ftp://ftp.chg.ru/pub/gnu/
     http://mirror.internode.on.net/pub/gnu/
-    http://mirror.pacific.net.au/pub1/gnu/gnu/
-    http://mirror.aarnet.edu.au/pub/GNU/
+    http://mirror.aarnet.edu.au/pub/gnu/
     ftp://ftp.gnu.org/gnu/
     http://ftp.gnu.org/gnu/
     ftp://ftp.gnu.org/old-gnu/
 }
 
 set portfetch::mirror_sites::sites(gnupg) {
-    http://www.mirrorservice.org/sites/ftp.gnupg.org/gcrypt/
+    ftp://gd.tuwien.ac.at/privacy/gnupg/
     http://ftp.freenet.de/pub/ftp.gnupg.org/gcrypt/
+    ftp://ftp.jyu.fi/pub/crypt/gcrypt/
     http://www.ring.gr.jp/pub/net/gnupg/
     ftp://ftp.gnupg.org/gcrypt/
-    http://ftp.gnupg.org/gcrypt/
 }
 
 set portfetch::mirror_sites::sites(gnustep) {
@@ -219,7 +220,6 @@ set portfetch::mirror_sites::sites(isc) {
     ftp://ftp.epix.net/pub/isc/
     ftp://ftp.nominum.com/pub/isc/
     http://mirrors.24-7-solutions.net/pub/isc/
-    http://www.mirrorservice.org/sites/ftp.isc.org/isc/
     ftp://gd.tuwien.ac.at/infosys/servers/isc/
     ftp://ftp.ciril.fr/pub/isc/
     ftp://ftp.grolier.fr/pub/isc/
@@ -238,10 +238,10 @@ set portfetch::mirror_sites::sites(isc) {
 }
 
 set portfetch::mirror_sites::sites(kde) {
+    http://mirrors.mit.edu/kde/
     http://ibiblio.org/pub/mirrors/kde/
     http://kde.mirrors.hoobly.com/
     http://ftp.gtlib.cc.gatech.edu/pub/kde/
-    http://www.mirrorservice.org/sites/ftp.kde.org/pub/kde/
     http://gd.tuwien.ac.at/kde/
     http://mirrors.isc.org/pub/kde/
     http://kde.mirrors.tds.net/pub/kde/
@@ -252,21 +252,33 @@ set portfetch::mirror_sites::sites(kde) {
     http://ftp.chg.ru/pub/kde/
     http://ftp.kddlabs.co.jp/pub/X11/kde/
     ftp://ftp.kde.org/pub/kde/
+    http://mirror.facebook.net/kde/
 }
 
 set portfetch::mirror_sites::sites(macports) {
     http://svn.macports.org/repository/macports/distfiles/
-    http://svn.macports.org/repository/macports/distfiles/general/:nosubdir
 }
 
 set portfetch::mirror_sites::sites(macports_distfiles) {
     http://distfiles.macports.org/:mirror
     http://aarnet.au.distfiles.macports.org/pub/macports/mpdistfiles/:mirror
     http://lil.fr.distfiles.macports.org/:mirror
+    http://sea.us.distfiles.macports.org/macports/mpdistfiles/:mirror
+    http://ykf.ca.distfiles.macports.org/MacPorts/mpdistfiles/:mirror
+}
+
+set portfetch::mirror_sites::sites(netbsd) {
+    http://ftp7.de.NetBSD.org/pub/ftp.netbsd.org/pub/NetBSD/
+    http://ftp.fr.NetBSD.org/pub/NetBSD/
+    ftp://ftp7.us.NetBSD.org/pub/NetBSD/
+    ftp://ftp.uk.NetBSD.org/pub/NetBSD/
+    ftp://ftp.tw.NetBSD.org/pub/NetBSD/
+    ftp://ftp7.jp.NetBSD.org/pub/NetBSD/
+    ftp://ftp.ru.NetBSD.org/pub/NetBSD/
+    http://ftp.NetBSD.org/pub/NetBSD/
 }
 
 set portfetch::mirror_sites::sites(openbsd) {
-    http://www.mirrorservice.org/sites/ftp.openbsd.org/pub/OpenBSD/
     ftp://carroll.cac.psu.edu/pub/OpenBSD/
     ftp://openbsd.informatik.uni-erlangen.de/pub/OpenBSD/
     ftp://gd.tuwien.ac.at/opsys/OpenBSD/
@@ -283,7 +295,6 @@ set portfetch::mirror_sites::sites(openbsd) {
 
 set portfetch::mirror_sites::sites(perl_cpan) {
     http://mirrors.ibiblio.org/pub/mirrors/CPAN/modules/by-module/
-    http://www.mirrorservice.org/sites/ftp.cpan.org/pub/CPAN/modules/by-module/
     http://ftp.ucr.ac.cr/Unix/CPAN/modules/by-module/
     ftp://ftp.funet.fi/pub/languages/perl/CPAN/modules/by-module/
     ftp://ftp.kddlabs.co.jp/lang/perl/CPAN/modules/by-module/
@@ -291,12 +302,12 @@ set portfetch::mirror_sites::sites(perl_cpan) {
     ftp://mirror.hiwaay.net/CPAN/modules/by-module/
     ftp://ftp.auckland.ac.nz/pub/perl/CPAN/modules/by-module/
     ftp://ftp.cs.colorado.edu/pub/perl/CPAN/modules/by-module/
-    ftp://cpan.pop-mg.com.br/pub/CPAN/modules/by-module/
     ftp://ftp.is.co.za/programming/perl/modules/by-module/
     ftp://ftp.chg.ru/pub/lang/perl/CPAN/modules/by-module/
     http://mirror.internode.on.net/pub/cpan/modules/by-module/
     http://cpan.mirrors.ilisys.com.au/modules/by-module/
     http://mirror.aarnet.edu.au/pub/CPAN/modules/by-module/
+    http://mirror.facebook.net/cpan/modules/by-module/
     ftp://ftp.cpan.org/pub/CPAN/modules/by-module/
 }
 
@@ -305,14 +316,16 @@ set portfetch::mirror_sites::sites(php) {
     http://de.php.net/distributions/:nosubdir
     http://es.php.net/distributions/:nosubdir
     http://fi.php.net/distributions/:nosubdir
-    http://fr.php.net/distributions/:nosubdir
-    http://gr.php.net/distributions/:nosubdir
+    http://fr2.php.net/distributions/:nosubdir
+    http://jp2.php.net/distributions/:nosubdir
+    http://uk2.php.net/distributions/:nosubdir
+    http://us.php.net/distributions/:nosubdir
+    http://us2.php.net/distributions/:nosubdir
     http://www.php.net/distributions/:nosubdir
 }
 
 set portfetch::mirror_sites::sites(postgresql) {
     http://ftp9.us.postgresql.org/pub/mirrors/postgresql/
-    http://www.mirrorservice.org/sites/ftp.postgresql.org/
     http://ftp7.de.postgresql.org/ftp.postgresql.org/
     ftp://ftp2.ch.postgresql.org/pub/mirrors/postgresql
     ftp://ftp.de.postgresql.org/mirror/postgresql/
@@ -325,7 +338,6 @@ set portfetch::mirror_sites::sites(postgresql) {
 
 set portfetch::mirror_sites::sites(ruby) {
     http://www.ibiblio.org/pub/languages/ruby/
-    http://www.mirrorservice.org/sites/ftp.ruby-lang.org/pub/ruby/
     http://mirrors.sunsite.dk/ruby/
     ftp://xyz.lcs.mit.edu/pub/ruby/
     ftp://ftp.iij.ad.jp/pub/lang/ruby/
@@ -333,8 +345,8 @@ set portfetch::mirror_sites::sites(ruby) {
     ftp://ftp.easynet.be/ruby/ruby/
     ftp://ftp.ntua.gr/pub/lang/ruby/
     ftp://ftp.chg.ru/pub/lang/ruby/
-    ftp://ftp.kr.FreeBSD.org/pub/ruby/
     ftp://ftp.iDaemons.org/pub/mirror/ftp.ruby-lang.org/ruby/
+    http://ftp.ruby-lang.org/pub/ruby/
     ftp://ftp.ruby-lang.org/pub/ruby/
 }
 
@@ -347,45 +359,56 @@ set portfetch::mirror_sites::sites(savannah) {
     ftp://mirror.cinquix.com/pub/savannah/
     http://mirror.csclub.uwaterloo.ca/nongnu/
     ftp://mirror.csclub.uwaterloo.ca/nongnu/
-    http://mirror.publicns.net/pub/nongnu/
-    ftp://mirror.publicns.net/pub/nongnu/
-    ftp://mirrors.localhost.net.ar/pub/mirrors/savannah-nongnu/
     http://mirrors.openfountain.cl/savannah/
     http://mirrors.zerg.biz/nongnu/
-    http://nongnu.askapache.com/
-    http://nongnu.bigsearcher.com/
     http://mirror.its.uidaho.edu/pub/savannah/
     ftp://mirror.its.uidaho.edu/savannah/
     http://piotrkosoft.net/pub/mirrors/savannah.gnu.org/
     ftp://ftp.piotrkosoft.net/pub/mirrors/savannah.gnu.org/
     http://savannah.c3sl.ufpr.br/
     ftp://savannah.c3sl.ufpr.br/savannah-nongnu/
-    http://savannah.inetbridge.net/
-    http://www.centervenus.com/mirrors/nongnu/
     http://www.de-mirrors.de/nongnu/
 }
 # Alias nongnu to savannah
 set portfetch::mirror_sites::sites(nongnu) $portfetch::mirror_sites::sites(savannah)
 
+# http://sourceforge.net/apps/trac/sourceforge/wiki/Mirrors
+# Do not add superb-east and superb-west; they don't seem to have current files.
+# See http://lists.macosforge.org/pipermail/macports-dev/2010-July/012387.html
 set portfetch::mirror_sites::sites(sourceforge) {
     http://downloads.sourceforge.net/
-    http://easynews.dl.sourceforge.net/
-    http://internap.dl.sourceforge.net/
-    http://superb-east.dl.sourceforge.net/
-    http://superb-west.dl.sourceforge.net/
-    http://voxel.dl.sourceforge.net/
-    http://ufpr.dl.sourceforge.net/
+    http://aarnet.dl.sourceforge.net/
+    http://biznetnetworks.dl.sourceforge.net/
+    http://cdnetworks-us-1.dl.sourceforge.net/
+    http://cdnetworks-us-2.dl.sourceforge.net/
+    http://cdnetworks-kr-1.dl.sourceforge.net/
+    http://cdnetworks-kr-2.dl.sourceforge.net/
+    http://citylan.dl.sourceforge.net/
     http://dfn.dl.sourceforge.net/
+    http://fastbull.dl.sourceforge.net/
+    http://freefr.dl.sourceforge.net/
     http://garr.dl.sourceforge.net/
     http://heanet.dl.sourceforge.net/
+    http://hivelocity.dl.sourceforge.net/
+    http://ignum.dl.sourceforge.net/
+    http://internode.dl.sourceforge.net/
+    http://iweb.dl.sourceforge.net/
+    http://jaist.dl.sourceforge.net/
     http://kent.dl.sourceforge.net/
     http://mesh.dl.sourceforge.net/
+    http://nchc.dl.sourceforge.net/
+    http://ncu.dl.sourceforge.net/
+    http://netcologne.dl.sourceforge.net/
+    http://puzzle.dl.sourceforge.net/
+    http://softlayer.dl.sourceforge.net/
+    http://space.dl.sourceforge.net/
+    http://sunet.dl.sourceforge.net/
     http://surfnet.dl.sourceforge.net/
     http://switch.dl.sourceforge.net/
-    http://nchc.dl.sourceforge.net/
-    http://internode.dl.sourceforge.net/
     http://transact.dl.sourceforge.net/
-    http://optusnet.dl.sourceforge.net/
+    http://ufpr.dl.sourceforge.net/
+    http://voxel.dl.sourceforge.net/
+    http://waix.dl.sourceforge.net/
 }
 
 set portfetch::mirror_sites::sites(sourceforge_jp) {
@@ -399,10 +422,12 @@ set portfetch::mirror_sites::sites(sourceforge_jp) {
 set portfetch::mirror_sites::sites(sunsite) {
     http://www.ibiblio.org/pub/Linux/
     http://www.gtlib.cc.gatech.edu/pub/Linux/
+    ftp://sunsite.unc.edu/pub/Linux/
     ftp://ftp.unicamp.br/pub/systems/Linux/
     ftp://ftp.tuwien.ac.at/pub/linux/ibiblio/
     ftp://ftp.cs.tu-berlin.de/pub/linux/Mirrors/sunsite.unc.edu/
     ftp://ftp.lip6.fr/pub/linux/sunsite/
+    http://ftp.surfnet.nl/pub/sunsite/
     ftp://ftp.nvg.ntnu.no/pub/mirrors/metalab.unc.edu/
     ftp://ftp.icm.edu.pl/vol/rzm1/linux-ibiblio/
     ftp://ftp.cse.cuhk.edu.hk/pub4/Linux/
@@ -411,7 +436,6 @@ set portfetch::mirror_sites::sites(sunsite) {
 }
 
 set portfetch::mirror_sites::sites(tcltk) {
-    http://www.mirrorservice.org/sites/ftp.tcl.tk/pub/tcl/
     ftp://mirror.switch.ch/mirror/tcl.tk/
     ftp://ftp.informatik.uni-hamburg.de/pub/soft/lang/tcl/
     ftp://ftp.funet.fi/pub/languages/tcl/tcl/
@@ -433,21 +457,22 @@ set portfetch::mirror_sites::sites(tex_ctan) {
     ftp://mirror.macomnet.net/pub/CTAN/
     http://ftp.sun.ac.za/ftp/CTAN/
     http://ftp.inf.utfsm.cl/pub/tex-archive/
-    http://ftp.das.ufsc.br/pub/ctan/
     ftp://ftp.tex.ac.uk/tex-archive/
     ftp://ftp.dante.de/tex-archive/
     ftp://ctan.tug.org/tex-archive/
 }
 
 set portfetch::mirror_sites::sites(trolltech) {
-    ftp://ftp.trolltech.com/qt/source/:nosubdir
     http://ftp.heanet.ie/mirrors/ftp.trolltech.com/pub/qt/source/:nosubdir
     ftp://ftp.informatik.hu-berlin.de/pub1/Mirrors/ftp.troll.no/QT/qt/source/:nosubdir
+    http://ftp.iasi.roedu.net/mirrors/ftp.trolltech.com/qt/source/:nosubdir
+    http://ftp.ntua.gr/pub/X11/Qt/qt/source/:nosubdir
+    http://get.qt.nokia.com/qt/source/:nosubdir
+    ftp://ftp.trolltech.com/qt/source/:nosubdir
 }
 
 set portfetch::mirror_sites::sites(xcontrib) {
     ftp://ftp.net.ohio-state.edu/pub/X11/contrib/
-    http://www.mirrorservice.org/sites/ftp.x.org/contrib/
     ftp://ftp.gwdg.de/pub/x11/x.org/contrib/
     http://mirror.aarnet.edu.au/pub/X11/contrib/
     ftp://ftp.chg.ru/pub/X11/x.org/contrib/
@@ -457,34 +482,32 @@ set portfetch::mirror_sites::sites(xcontrib) {
 
 set portfetch::mirror_sites::sites(xfree) {
     http://www.gtlib.cc.gatech.edu/pub/XFree86/
-    http://www.mirrorservice.org/sites/ftp.xfree86.org/pub/XFree86/
     http://ftp-stud.fht-esslingen.de/pub/Mirrors/ftp.xfree86.org/XFree86/
     ftp://ftp.fit.vutbr.cz/pub/XFree86/
-    ftp://mir1.ovh.net/ftp.xfree86.org/
     ftp://ftp.gwdg.de/pub/xfree86/XFree86/
-    ftp://ftp.rediris.es/mirror/XFree86/
     ftp://ftp.esat.net/pub/X11/XFree86/
-    ftp://sunsite.uio.no/pub/XFree86/
     ftp://ftp.physics.uvt.ro/pub/XFree86/
-    ftp://ftp.chg.ru/pub/XFree86/
-    http://mirror.aarnet.edu.au/pub/XFree86/
+    http://mirror.aarnet.edu.au/pub/xfree86/
     ftp://ftp.xfree86.org/pub/XFree86/
 }
 
 set portfetch::mirror_sites::sites(xorg) {
-    http://x.paracoda.com/pub/
-    http://www.mirrorservice.org/sites/ftp.x.org/pub/
+    http://mirror.csclub.uwaterloo.ca/x.org/
+    http://mirror.switch.ch/ftp/mirror/X11/pub/
     ftp://ftp.gwdg.de/pub/x11/x.org/pub/
-    ftp://ftp.cs.cuhk.edu.hk/pub/X11/
-    http://ftp.nara.wide.ad.jp/pub/X11/x.org/pub/
-    http://www.qtopia.org.cn/ftp/mirror/ftp.x.org/pub/
-    ftp://ftp.cica.es/pub/X/pub/
+    http://ftp.cica.es/mirrors/X/pub/
+    http://mirror.cict.fr/x.org/pub/
     ftp://ftp.ntua.gr/pub/X11/X.org/
+    ftp://ftp.cs.cuhk.edu.hk/pub/X11/
+    http://mi.mirror.garr.it/mirrors/x.org/
+    http://ftp.nara.wide.ad.jp/pub/X11/x.org/
+    ftp://sunsite.uio.no/pub/X11/
     ftp://ftp.task.gda.pl/mirror/ftp.x.org/pub/
     ftp://ftp.sunet.se/pub/X11/ftp.x.org/
-    ftp://sunsite.uio.no/pub/X11/
-    ftp://ftp.chg.ru/pub/X11/x.org/pub/
+    http://x.cs.pu.edu.tw/
     ftp://ftp.is.co.za/pub/x.org/pub/
+    http://xorg.freedesktop.org/archive/
     http://xorg.freedesktop.org/releases/
+    http://www.x.org/pub/
     ftp://ftp.x.org/pub/
 }
