@@ -1,7 +1,7 @@
 # -*- coding: utf-8; mode: tcl; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- vim:fenc=utf-8:ft=tcl:et:sw=4:ts=4:sts=4
 # muniversal-1.0.tcl
 #
-# $Id: muniversal-1.0.tcl 54754 2009-08-01 19:26:04Z jmr@macports.org $
+# $Id: muniversal-1.0.tcl 79694 2011-06-23 18:32:11Z jmr@macports.org $
 #
 # Copyright (c) 2009 The MacPorts Project,
 # All rights reserved.
@@ -34,9 +34,10 @@
 
 # User variables:
 #         merger_configure_env: associative array of configure.env variables
-#             merger_build_env: assoicative array of build.env variables
+#             merger_build_env: associative array of build.env variables
 #                  merger_host: associative array of host values
 #        merger_configure_args: associative array of configure.args
+#            merger_build_args: associative array of build.args
 #    merger_configure_cppflags: associative array of configure.cppflags
 #      merger_configure_cflags: associative array of configure.cflags
 #    merger_configure_cxxflags: associative array of configure.cxxflags
@@ -44,7 +45,7 @@
 #     merger_configure_ldflags: associative array of configure.ldflags
 #             merger_arch_flag: if no, -arch xxx will not be appended configure.???flags
 #         merger_arch_compiler: if no, -arch xxx will not be appended to compilers
-#          merger_destroot_env: assoicative array of desroot.env variables
+#          merger_destroot_env: associative array of destroot.env variables
 #             merger_dont_diff: list of file names for which diff will not work
 #     merger_must_run_binaries: if yes, build platform must be able to run binaries for supported architectures
 #            merger_no_3_archs: if yes, merger will not work correctly if there are three supported architectures
@@ -73,10 +74,10 @@ proc muniversal_arch_flag_supported {args} {
     }
 }
 
-proc muniversal_get_arch_flag {arch} {
+proc muniversal_get_arch_flag {arch {fortran ""}} {
     global os.arch
     # Prefer -arch to -m
-    if {[muniversal_arch_flag_supported]} {
+    if {[muniversal_arch_flag_supported] && ${fortran}==""} {
         set archf "-arch ${arch}"
     } else {
         if { ${os.arch}=="i386" && ${arch}=="i386" } {
@@ -88,7 +89,11 @@ proc muniversal_get_arch_flag {arch} {
         } elseif { ${os.arch}=="powerpc" && ${arch}=="ppc64" } {
             set archf -m64
         } else {
-            return -code error "selected compiler can't build for ${arch}"
+            if { ${fortran}=="" } {
+                return -code error "selected compiler can't build for ${arch}"
+            } else {
+                return ""
+            }
         }
     }
     return ${archf}
@@ -101,15 +106,6 @@ variant universal {
         configure.universal_cflags-delete    -arch ${arch}
         configure.universal_cxxflags-delete  -arch ${arch}
         configure.universal_ldflags-delete   -arch ${arch}
-        configure.cflags-delete    -arch ${arch}
-        configure.cxxflags-delete  -arch ${arch}
-        configure.ldflags-delete   -arch ${arch}
-    }
-    # workaround for #17865 (deleting all option contents also deletes the option)
-    foreach flags {universal_cflags universal_cxxflags universal_ldflags cflags cxxflags ldflags} {
-        if {![info exists configure.${flags}]} {
-            configure.${flags}
-        }
     }
 
     eval configure.args-append      ${configure.universal_args}
@@ -119,26 +115,19 @@ variant universal {
     eval configure.ldflags-append   ${configure.universal_ldflags}
     eval configure.cppflags-append  ${configure.universal_cppflags}
 
-    # undo setting of --host and --target from portconfigure.tcl procedure configure_get_universal_args
-    # XXX Quick hack for base after r49087
-    if {[llength [info commands "portconfigure::*"]] > 0} {
-        # XXX even more hackery, since portconfigure::configure_get_universal_system_name is gone on trunk
-        set undo_system_value ""
-    } else {
-        set undo_system_value [configure_get_universal_system_name]
-    }
-    if {[llength ${configure.universal_archs}] == 1 &&
-        [info exists undo_system_value] && $undo_system_value != ""} {
-        configure.args-delete --host=${undo_system_value} --target=${undo_system_value}
-    }
-
     # user has specified that build platform must be able to run binaries for supported architectures
     if { ${merger_must_run_binaries}=="yes" } {
         if { ${os.arch}=="i386" } {
             set universal_archs_supported [ldelete ${universal_archs_supported} "ppc64"]
+            if {${os.major} >= 9 && [sysctl hw.cpu64bit_capable] == 0} {
+                set universal_archs_supported [ldelete ${universal_archs_supported} "x86_64"]
+            }
         } else {
             set universal_archs_supported [ldelete ${universal_archs_supported} "i386"]
             set universal_archs_supported [ldelete ${universal_archs_supported} "x86_64"]
+            if {${os.major} >= 9 && [sysctl hw.cpu64bit_capable] == 0} {
+                set universal_archs_supported [ldelete ${universal_archs_supported} "ppc64"]
+            }
         }
     }
 
@@ -181,20 +170,24 @@ variant universal {
     }
 
     configure {
+        # Fix inability to find nm when cross-compiling (#22224, #23431, #23687, #24477, et al)
+        configure.env-append    NM=/usr/bin/nm
+
         foreach arch ${universal_archs_to_use} {
-            ui_msg "$UI_PREFIX [format [msgcat::mc "Configuring %1\$s for architecture %2\$s"] $name ${arch}]"
+            ui_info "$UI_PREFIX [format [msgcat::mc "Configuring %1\$s for architecture %2\$s"] $name ${arch}]"
 
             copy ${worksrcpath} ${worksrcpath}-${arch}
 
             set archf [muniversal_get_arch_flag ${arch}]
+            set archff [muniversal_get_arch_flag ${arch} "fortran"]
 
             if { ${merger_arch_flag} != "no" } {
                 configure.cflags-append    ${archf}
                 configure.cxxflags-append  ${archf}
                 configure.objcflags-append ${archf}
-                configure.fflags-append    ${archf}
-                configure.fcflags-append   ${archf}
-                configure.f90flags-append  ${archf}
+                configure.fflags-append    ${archff}
+                configure.fcflags-append   ${archff}
+                configure.f90flags-append  ${archff}
                 configure.ldflags-append   ${archf}
             }
 
@@ -219,32 +212,37 @@ variant universal {
 
             # Don't set the --host unless we have to.
             set host ""
-            if { ${os.arch}=="i386" && (${arch}=="ppc" || ${arch}=="ppc64") } {
-                if { [info exists merger_host(${arch})] } {
-                    if { $merger_host(${arch}) != "" } {
-                        set host  --host=$merger_host(${arch})
-                    }
-                } else {
-                    if { ${arch}=="ppc" } {
-                        set host --host=powerpc-apple-darwin${os.version}
-                    } else {
-                        set host --host=powerpc64-apple-darwin${os.version}
-                    }
+            if { [info exists merger_host($arch)] } {
+                if { $merger_host($arch) != "" } {
+                    set host  --host=$merger_host($arch)
                 }
-            } elseif { ${os.arch}=="powerpc" && (${arch}=="i386" || ${arch}=="x86_64") } {
-                if { [info exists merger_host(${arch})] } {
-                    if { $merger_host(${arch}) != "" } {
-                        set host  --host=$merger_host(${arch})
-                    }
-                } else {
-                    if { ${arch}=="i386" } {
-                        set host --host=i386-apple-darwin${os.version}
+            } else {
+                # check if building for a word length we can't run
+                set bits_differ 0
+                if {(${arch}=="x86_64" || ${arch}=="ppc64") &&
+                    (${os.major} < 9 || [sysctl hw.cpu64bit_capable] == 0)} {
+                    set bits_differ 1
+                }
+                # check if building for a completely different arch
+                if {$bits_differ || (${os.arch}=="i386" && (${arch}=="ppc" || ${arch}=="ppc64"))
+                        || (${os.arch}=="powerpc" && (${arch}=="i386" || ${arch}=="x86_64"))
+                        || $macosx_deployment_target != $macosx_version} {
+                    if {$macosx_deployment_target == $macosx_version} {
+                        set hostversion ${os.version}
                     } else {
-                        set host --host=x86_64-apple-darwin${os.version}
+                        set hostversion [expr [lindex [split $macosx_deployment_target .] 1] + 4]
+                    }
+                    switch -- ${arch} {
+                        x86_64  {set host "--host=x86_64-apple-${os.platform}${hostversion}"}
+                        i386    {set host "--host=i686-apple-${os.platform}${hostversion}"}
+                        ppc     {set host "--host=powerpc-apple-${os.platform}${hostversion}"}
+                        ppc64   {set host "--host=powerpc64-apple-${os.platform}${hostversion}"}
                     }
                 }
             }
-            configure.args-append  ${host}
+            if {$host != ""} {
+                configure.args-append  ${host}
+            }
 
             if { [info exists merger_configure_args(${arch})] } {
                 configure.args-append  $merger_configure_args(${arch})
@@ -261,9 +259,9 @@ variant universal {
                 configure.cc   ${configure.cc}   ${archf}
                 configure.cxx  ${configure.cxx}  ${archf}
                 configure.objc ${configure.objc} ${archf}
-                if { ${configure.fc}  != "" } { configure.fc   ${configure.fc}  ${archf} }
-                if { ${configure.f77} != "" } { configure.f77  ${configure.f77} ${archf} }
-                if { ${configure.f90} != "" } { configure.f90  ${configure.f90} ${archf} }
+                if { ${configure.fc}  != "" } { configure.fc   ${configure.fc}  ${archff} }
+                if { ${configure.f77} != "" } { configure.f77  ${configure.f77} ${archff} }
+                if { ${configure.f90} != "" } { configure.f90  ${configure.f90} ${archff} }
             }
 
             set configure_dir_save  ${configure.dir}
@@ -290,12 +288,7 @@ variant universal {
                 }
             }
 
-            # XXX Quick hack for base after r49087
-            if {[llength [info commands "portconfigure::*"]] > 0} {
-                portconfigure::configure_main
-            } else {
-                configure_main
-            }
+            portconfigure::configure_main
 
             # Undo changes to the configure related variables
             eval autoreconf.dir ${autoreconf_dir_save}
@@ -330,9 +323,9 @@ variant universal {
             }
             if { ${merger_arch_flag} != "no" } {
                 configure.ldflags-delete   ${archf}
-                configure.f90flags-delete  ${archf}
-                configure.fcflags-delete   ${archf}
-                configure.fflags-delete    ${archf}
+                configure.f90flags-delete  ${archff}
+                configure.fcflags-delete   ${archff}
+                configure.fflags-delete    ${archff}
                 configure.objcflags-delete ${archf}
                 configure.cxxflags-delete  ${archf}
                 configure.cflags-delete    ${archf}
@@ -342,11 +335,14 @@ variant universal {
 
     build {
         foreach arch ${universal_archs_to_use} {
-            ui_msg "$UI_PREFIX [format [msgcat::mc "Building %1\$s for architecture %2\$s"] $name ${arch}]"
+            ui_info "$UI_PREFIX [format [msgcat::mc "Building %1\$s for architecture %2\$s"] $name ${arch}]"
             
             if { [info exists merger_build_env(${arch})] } {
                 build.env-append  $merger_build_env(${arch})
             }
+            if { [info exists merger_build_args(${arch})] } {
+                build.args-append  $merger_build_args(${arch})
+            }
             set build_dir_save  ${build.dir}
             if { [string match "${worksrcpath}/*" ${build.dir}] } {
                 # The build directory is inside the source directory, so put in the new source directory name.
@@ -358,12 +354,13 @@ variant universal {
                     file mkdir ${build.dir}
                 }
             }
-            if {[llength [info commands "portbuild::*"]] > 0} {
-                portbuild::build_main
-            } else {
-                build_main
-            }
+
+            portbuild::build_main
+
             eval build.dir  ${build_dir_save}
+            if { [info exists merger_build_args(${arch})] } {
+                build.args-delete $merger_build_args(${arch})
+            }
             if { [info exists merger_build_env(${arch})] } {
                 build.env-delete  $merger_build_env(${arch})
             }
@@ -372,7 +369,7 @@ variant universal {
 
     destroot {
         foreach arch ${universal_archs_to_use} {
-            ui_msg "$UI_PREFIX [format [msgcat::mc "Staging %1\$s into destroot for architecture %2\$s"] $name ${arch}]"
+            ui_info "$UI_PREFIX [format [msgcat::mc "Staging %1\$s into destroot for architecture %2\$s"] $name ${arch}]"
             copy ${destroot} ${workpath}/destroot-${arch}
             set destdirSave ${destroot.destdir}
             eval destroot.destdir  [string map "${destroot} ${workpath}/destroot-${arch}" ${destroot.destdir}]
@@ -391,11 +388,9 @@ variant universal {
                     file mkdir ${destroot.dir}
                 }
             }
-            if {[llength [info commands "portdestroot::*"]] > 0} {
-                portdestroot::destroot_main
-            } else {
-                destroot_main
-            }
+
+            portdestroot::destroot_main
+
             destroot.dir  ${destroot_dir_save}
             if { [info exists merger_destroot_env(${arch})] } {
                 destroot.env-delete  $merger_destroot_env(${arch})
@@ -405,7 +400,7 @@ variant universal {
         delete ${destroot}
 
         # Merge ${base1}/${prefixDir} and ${base2}/${prefixDir} into dir ${base}/${prefixDir}
-        #        arch1, arch2: names to prepend to files if a diff merge of two files is forbiddend by merger_dont_diff
+        #        arch1, arch2: names to prepend to files if a diff merge of two files is forbidden by merger_dont_diff
         #    merger_dont_diff: list of files for which /usr/bin/diff ${diffFormat} will not merge correctly
         #          diffFormat: format used by diff to merge two text files
         proc merge2Dir {base1 base2 base prefixDir arch1 arch2 merger_dont_diff diffFormat} {
@@ -451,13 +446,13 @@ variant universal {
                         merge2Dir ${base1} ${base2} ${base} ${prefixDir}/${fl} ${arch1} ${arch2} ${merger_dont_diff} ${diffFormat}
                     } else {
                         # Files are neither directories nor links
-                        if { ! [catch {system "/usr/bin/cmp ${dir1}/${fl} ${dir2}/${fl} && /bin/cp -v ${dir1}/${fl} ${dir}"}] } {
+                        if { ! [catch {system "/usr/bin/cmp \"${dir1}/${fl}\" \"${dir2}/${fl}\" && /bin/cp -v \"${dir1}/${fl}\" \"${dir}\""}] } {
                             # Files are byte by byte the same
                             ui_debug "universal: merge: ${prefixDir}/${fl} is identical in ${base1} and ${base2}"
                         } else {
                             # Actually try to merge the files
                             # First try lipo
-                            if { ! [catch {system "/usr/bin/lipo -create ${dir1}/${fl} ${dir2}/${fl} -output ${dir}/${fl}"}] } {
+                            if { ! [catch {system "/usr/bin/lipo -create \"${dir1}/${fl}\" \"${dir2}/${fl}\" -output \"${dir}/${fl}\""}] } {
                                 # lipo worked
                                 ui_debug "universal: merge: lipo created ${prefixDir}/${fl}"
                             } else {
@@ -482,7 +477,7 @@ variant universal {
 
                                     ui_debug "universal: merge: created ${prefixDir}/${fl} to include ${prefixDir}/${arch1}-${fl} ${prefixDir}/${arch1}-${fl}"
 
-                                    system "/usr/bin/diff -d ${diffFormat} ${dir}/${arch1}-${fl} ${dir}/${arch2}-${fl} > ${dir}/${fl}; test \$? -le 1"
+                                    system "/usr/bin/diff -d ${diffFormat} \"${dir}/${arch1}-${fl}\" \"${dir}/${arch2}-${fl}\" > \"${dir}/${fl}\"; test \$? -le 1"
 
                                     copy -force ${dir1}/${fl} ${dir}/${arch1}-${fl}
                                     copy -force ${dir2}/${fl} ${dir}/${arch2}-${fl}
@@ -506,10 +501,15 @@ variant universal {
                                                 copy ${dir1}/${fl} ${dir}/mods64
                                             }
                                         }
+                                        *.la -
+                                        *.pc -
+                                        *-config {
+                                            return -code error "${prefixDir}/${fl} differs in ${base1} and ${base2} and cannot be merged"
+                                        }
                                     }
 
                                     if { ${known_file}=="no" } {
-                                        if { ! [catch {system "/usr/bin/diff -dw ${diffFormat} ${dir1}/${fl} ${dir2}/${fl} > ${dir}/${fl}; test \$? -le 1"} ] } {
+                                        if { ! [catch {system "/usr/bin/diff -dw ${diffFormat} \"${dir1}/${fl}\" \"${dir2}/${fl}\" > \"${dir}/${fl}\"; test \$? -le 1"} ] } {
                                             # diff worked
                                             ui_debug "universal: merge: used diff to create ${prefixDir}/${fl}"
                                         } else {
@@ -519,17 +519,56 @@ variant universal {
                                             # nothing has worked so far.
                                             switch -glob ${fl} {
                                                 *.jar {
-                                                    # jar files can be different becasue of timestamp
-                                                    ui_debug "universal: merge: ${prefixDir}/${fl} is different in ${base1} and ${base2}; assume timestamp difference"
+                                                    # jar files can be different because of timestamp
+                                                    ui_debug "universal: merge: ${prefixDir}/${fl} differs in ${base1} and ${base2}; assume timestamp difference"
                                                     copy ${dir1}/${fl} ${dir}
                                                 }
                                                 *.elc {
-                                                    # elc files can be differet because they record when and where they were built.
-                                                    ui_debug "universal: merge: ${prefixDir}/${fl} is different in ${base1} and ${base2}; assume trivial difference"
+                                                    # elc files can be different because they record when and where they were built.
+                                                    ui_debug "universal: merge: ${prefixDir}/${fl} differs in ${base1} and ${base2}; assume trivial difference"
                                                     copy ${dir1}/${fl} ${dir}
                                                 }
+                                                *.gz -
+                                                *.bz2 {
+                                                    # compressed files can differ due to entropy
+                                                    switch -glob ${fl} {
+                                                        *.gz {
+                                                            set cat /usr/bin/gzcat
+                                                        }
+                                                        *.bz2 {
+                                                            set cat /usr/bin/bzcat
+                                                        }
+                                                    }
+                                                    set tempdir [mkdtemp "/tmp/muniversal.XXXXXXXX"]
+                                                    set tempfile1 "${tempdir}/${arch1}-[file rootname ${fl}]"
+                                                    set tempfile2 "${tempdir}/${arch2}-[file rootname ${fl}]"
+                                                    system "${cat} \"${dir1}/${fl}\" > \"${tempfile1}\""
+                                                    system "${cat} \"${dir2}/${fl}\" > \"${tempfile2}\""
+                                                    set identical "no"
+                                                    if { ! [catch {system "/usr/bin/cmp -s \"${tempfile1}\" \"${tempfile2}\""}] } {
+                                                        # files are identical
+                                                        ui_debug "universal: merge: ${prefixDir}/${fl} differs in ${base1} and ${base2} but the contents are the same"
+                                                        set identical "yes"
+                                                        copy ${dir1}/${fl} ${dir}
+                                                    }
+                                                    if { ${identical}=="no" } {
+                                                        switch -glob ${fl} {
+                                                            *.el.gz {
+                                                                # Emacs lisp files should be same across architectures
+                                                                # the emacs package (and perhaps others) records the date of automatically generated el files
+                                                                ui_debug "universal: merge: ${prefixDir}/${fl} differs in ${base1} and ${base2}; assume trivial difference"
+                                                                set identical "yes"
+                                                                copy ${dir1}/${fl} ${dir}
+                                                            }
+                                                        }
+                                                    }
+                                                    delete ${tempfile1} ${tempfile2} ${tempdir}
+                                                    if {${identical}=="no"} {
+                                                        return -code error "${prefixDir}/${fl} differs in ${base1} and ${base2} and cannot be merged"
+                                                    }
+                                                }
                                                 default {
-                                                    error "Can not create ${prefixDir}/${fl} from ${base1} and ${base2}"
+                                                    return -code error "${prefixDir}/${fl} differs in ${base1} and ${base2} and cannot be merged"
                                                 }
                                             }
                                         }
@@ -546,15 +585,15 @@ variant universal {
         # See http://www.gnu.org/software/diffutils/manual/html_mono/diff.html#If-then-else
         # See http://www.gnu.org/software/diffutils/manual/html_mono/diff.html#Detailed%20If-then-else
         set diffFormatProc {--old-group-format='#if (defined(__ppc__) || defined(__ppc64__))
- %<#endif /* __ppc__ || __ppc64__ */
+ %<#endif
 ' \
 --new-group-format='#if defined (__i386__) || defined(__x86_64__)
-%>#endif /* __i386__ || __x86_64__ */
+%>#endif
 ' \
 --unchanged-group-format='%=' \
 --changed-group-format='#if (defined(__ppc__) || defined(__ppc64__))
-%<#else /* ! __ppc__ && ! __ppc64__ */
-%>#endif /* __ppc__ || __ppc64__ */
+%<#else
+%>#endif
 '}
 
         set diffFormatM "-D __LP64__"
@@ -573,7 +612,7 @@ variant universal {
             # Rosetta does not translate G5 instructions
             # PowerPC systems can't translate Intel instructions
             if { (${os.arch}=="i386" && ${arch}!="ppc64") || (${os.arch}=="powerpc" && ${arch}!="i386" && ${arch}!="x86_64") } {
-                ui_msg "$UI_PREFIX [format [msgcat::mc "Testing %1\$s for architecture %2\$s"] $name ${arch}]"
+                ui_info "$UI_PREFIX [format [msgcat::mc "Testing %1\$s for architecture %2\$s"] $name ${arch}]"
                 set test_dir_save ${test.dir}
                 if { [string match "${worksrcpath}/*" ${test.dir}] } {
                     # The test directory is inside the source directory, so put in the new source directory name.
@@ -585,11 +624,9 @@ variant universal {
                         file mkdir ${test.dir}
                     }
                 }
-                if {[llength [info commands "porttest::*"]] > 0} {
-                    porttest::test_main
-                } else {
-                    test_main
-                }
+
+                porttest::test_main
+
                 test.dir ${test_dir_save}
             }
         }
