@@ -1,4 +1,4 @@
-# $Id: php5extension-1.0.tcl 63197 2010-01-29 08:03:35Z jmr@macports.org $
+# $Id: php5extension-1.0.tcl 79424 2011-06-13 08:03:13Z ryandesign@macports.org $
 # 
 # Copyright (c) 2009 The MacPorts Project
 # All rights reserved.
@@ -53,13 +53,15 @@ options php5extension.build_dirs
 default php5extension.build_dirs    {[php5extension.build_dirs_proc]}
 options php5extension.extensions
 options php5extension.extension_dir
-default php5extension.extension_dir {[exec ${prefix}/bin/php-config --extension-dir]}
+default php5extension.extension_dir {[exec ${prefix}/bin/php-config --extension-dir 2>/dev/null]}
 options php5extension.ini
 default php5extension.ini           {[lindex ${php5extension.extensions} 0].ini}
 options php5extension.inidir
 default php5extension.inidir        {${prefix}/var/db/php5}
 options php5extension.php_ini
 default php5extension.php_ini       {${prefix}/etc/php5/php.ini}
+options php5extension.phpize
+default php5extension.phpize        {${prefix}/bin/phpize}
 options php5extension.type
 default php5extension.type      php
 options php5extension.source
@@ -79,7 +81,7 @@ proc php5extension.setup {extensions version {source ""}} {
     categories                  php
     distname                    [lindex ${php5extension.extensions} 0]-${version}
     
-    depends_lib                 path:bin/phpize:php5
+    depends_lib                 path:bin/php:php5
     
     configure.universal_args-delete --disable-dependency-tracking
     
@@ -96,7 +98,7 @@ proc php5extension.setup {extensions version {source ""}} {
         }
         foreach dir ${php5extension.build_dirs} {
             ui_debug "Generating configure script in [file tail ${dir}]"
-            system "cd ${dir} && ${prefix}/bin/phpize"
+            system "cd ${dir} && ${php5extension.phpize}"
         }
     }
     
@@ -189,7 +191,7 @@ proc php5extension.setup {extensions version {source ""}} {
         }
         
         pre-configure {
-            set php_version [exec ${prefix}/bin/php-config --version]
+            set php_version [exec ${prefix}/bin/php-config --version 2>/dev/null]
             if {${version} != ${php_version}} {
                 ui_error "${name} ${version} requires PHP ${version} but you have PHP ${php_version}."
                 return -code error "incompatible PHP installation"
