@@ -1,9 +1,9 @@
 # et:ts=4
-# python31-1.0.tcl
+# python24-1.0.tcl
 #
-# $Id: python31-1.0.tcl 68551 2010-06-06 07:17:50Z jmr@macports.org $
+# $Id: python24-1.0.tcl 78508 2011-05-10 08:33:40Z jmr@macports.org $
 #
-# Copyright (c) 2007 Markus W. Weissman <mww@macports.org>,
+# Copyright (c) 2004 Markus W. Weissman <mww@macports.org>,
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -32,26 +32,29 @@
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #
 
-set python.branch	3.1
-set python.prefix	${frameworks_dir}/Python.framework/Versions/${python.branch}
-set python.bin	${python.prefix}/bin/python${python.branch}
-set python.lib	${python.prefix}/Python
-set python.libdir ${python.prefix}/lib/python${python.branch}
-set python.pkgd	${python.prefix}/lib/python${python.branch}/site-packages
-set python.include	${python.prefix}/include/python${python.branch}
+set python.branch	2.4
+set python.bin	${prefix}/bin/python${python.branch}
+set python.lib	${prefix}/lib/libpython${python.branch}.dylib
+set python.pkgd	${prefix}/lib/python${python.branch}/site-packages
+set python.libdir	${frameworks_dir}/Python.framework/Versions/${python.branch}/lib/python${python.branch}
+set python.include	${frameworks_dir}/Python.framework/Versions/${python.branch}/include/python${python.branch}
+if {![file isfile ${python.include}/Python.h] &&
+    ([file isfile ${prefix}/include/python${python.branch}/Python.h] || [string match *64* $build_arch])} {
+    set python.libdir	${prefix}/lib/python${python.branch}
+    set python.include	${prefix}/include/python${python.branch}
+}
 
 categories		python
 
 dist_subdir		python
 
-depends_lib		port:python31
+depends_lib		port:python24
 
-# we want the default universal variant added, so use a bad hack for 1.8
-set xcode.project ""
-use_configure   no
+# we want the default universal variant added despite not using configure
+use_configure	no
 universal_variant yes
 
-build.cmd		${python.bin} setup.py --no-user-cfg
+build.cmd		${python.bin} setup.py
 build.target	build
 options python.add_archflags
 default python.add_archflags yes
@@ -68,32 +71,15 @@ pre-build {
                              CXXFLAGS="${configure.cxx_archflags}" \
                              FFLAGS="${configure.f77_archflags}" \
                              F90FLAGS="${configure.f90_archflags}" \
-                             FCFLAGS="${configure.fc_archflags}"
-            if {[info exists configure.ld_archflags]} {
-                build.env-append LDFLAGS="${configure.ld_archflags}"
-            } else {
-                build.env-append LDFLAGS="${configure.cc_archflags}"
-            }
+                             FCFLAGS="${configure.fc_archflags}" \
+                             LDFLAGS="${configure.ld_archflags}"
         }
     }
 }
 
-destroot.cmd	${python.bin} setup.py --no-user-cfg
-destroot.destdir	--prefix=${python.prefix} --root=${destroot}
+destroot.cmd	${python.bin} setup.py
+destroot.destdir	--prefix=${prefix} --root=${destroot}
 
 pre-destroot	{
 	xinstall -d -m 755 ${destroot}${prefix}/share/doc/${name}/examples
 }
-
-options         python.link_binaries python.link_binaries_suffix
-default python.link_binaries yes
-default python.link_binaries_suffix {-${python.branch}}
-post-destroot {
-    if {${python.link_binaries}} {
-        foreach bin [glob -nocomplain -tails -directory "${destroot}${python.prefix}/bin" *] {
-            if {[catch {file type "${destroot}${prefix}/bin/${bin}${python.link_binaries_suffix}"}]} {
-                ln -s "${python.prefix}/bin/${bin}" "${destroot}${prefix}/bin/${bin}${python.link_binaries_suffix}"
-            }
-        }
-    }
-}
